/*-------------------------------------------------------------------
Name......... config.c
Author....... Marc Adams
Date......... 15/09/03
Description.. Configuration data specifying the hardware attached to
............. the system
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

/****   Include Files */


#include    "hardware.h"
#include    "peripherals.h"
#include    "customperiph.h"
#include	"interface.h"
#include    "config.h"
#include    "fpga.h"
#include    "palettes.h"

#include    "config.sp"

const   WORD    IMask1ms=6;
const   WORD    IMask10ms=2;
const   WORD    IMask250ms=1;

/****   Security */
const   LONG    SecStart=0;
const   LONG    SecEnd=0;

/****   Interrupts */

void (*Int1msLst[])()={0,0,0,0,0,0,0,0,0,EOF_FUNCTIONS};
void (*Int10msLst[])()={0,0,0,0,0,0,0,0,0,EOF_FUNCTIONS};
void (*Int250msLst[])()={0,0,0,0,0,0,0,0,0,EOF_FUNCTIONS};
void (*IntDuartLst[])()={0,0,0,0,EOF_FUNCTIONS};

void (*IntVideoLst[])()={0,0,0,0,0,0,0,0,0,EOF_FUNCTIONS};
void (*IntVideo0Lst[])()={0,0,0,0,0,0,0,0,0,EOF_FUNCTIONS};
void (*IntVideo1Lst[])()={0,0,0,0,0,0,0,0,0,EOF_FUNCTIONS};

void (*IntFpuartLst[])()={0,0,0,0,0,0,EOF_FUNCTIONS};
void (*IntDMALst[])()={0,0,0,0,EOF_FUNCTIONS};

/****   Inputs */

const   INPUTCFG    InputCfg[]=
{
    {3},                                /* Debounce sample time */
};

/* boot security */
const	ULONG	SecurityFlag = SECURITY_DISABLED;

/****   Multiplexed Inputs */

INPUTMAP    MxiInputMap[2];
const   WORD    MxiStrobeLst[]={-1};

/****   Outputs */
const   OUTPUT  VOPList[]={EOF_OUTPUTS};
const   OUTPUTCFG   OutputCfg[]=
{
    {VOPList}
};

/****   Serial Communications - Coldfire Serial module configuration and buffers */
BYTE    SerialModTxABuffer[1<<4]={0};
BYTE    SerialModRxABuffer[1<<4]={0};
BYTE    SerialModTxBBuffer[1<<4]={0};
BYTE    SerialModRxBBuffer[1<<4]={0};

const   WORD    SerialModTxAMask=sizeof(SerialModTxABuffer)-1;
const   WORD    SerialModRxAMask=sizeof(SerialModRxABuffer)-1;
const   WORD    SerialModTxBMask=sizeof(SerialModTxBBuffer)-1;
const   WORD    SerialModRxBMask=sizeof(SerialModRxBBuffer)-1;


const SERIALCFG SerialModuleCfg[] =
{
    { 0xDD, 0x03, 0x50, 0xDD, 0x03, 0x51,
      BAUD9600, BAUD9600, BITS8, STOPBITS, PARITYNONE, TXNONE, RXNONE,   /* Channel A */
      BAUD9600, BAUD9600, BITS8, STOPBITS, PARITYNONE, TXNONE, RXNONE  } /* Channel B */
};

/****   Serial Communications - FPGA UART configuration and buffers */

/* Serial Communications Fpga Uart 0 */

BYTE    FPuart0TxBuffer[1<<4]={0};

BYTE    FPuart0RxBuffer[1<<4]={0};

const   FPUARTCFG   FPUART0Cfg[]=
{
    { ( void *) FPGA_UART0_BASE,
      FPuart0ISR,
      FPuart0TxBuffer,
      FPuart0RxBuffer,
      sizeof( FPuart0TxBuffer ) - 1,
      sizeof( FPuart0RxBuffer ) - 1 }
};


/* Serial Communications Fpga Uart 1 */
BYTE    FPuart1TxBuffer[1<<4]={0};
BYTE    FPuart1RxBuffer[1<<4]={0};

const   FPUARTCFG   FPUART1Cfg[]=
{
    { (void*)FPGA_UART1_BASE,
      FPuart1ISR,
      FPuart1TxBuffer,
      FPuart1RxBuffer,
      sizeof( FPuart1TxBuffer ) - 1,
      sizeof( FPuart1RxBuffer ) - 1 }
};

/****   Serial Communications - 68692 DUART0 configuration and buffers */
static BYTE Duart0TxABuffer[1<<4]={0};
static BYTE Duart0RxABuffer[1<<4]={0};
static BYTE Duart0TxBBuffer[1<<4]={0};
static BYTE Duart0RxBBuffer[1<<4]={0};

const   DUARTCFG    DUART0Cfg[]=
    {
        {
        DUART0BASE,
        Duart0ISR,
        Duart0TxABuffer,
        Duart0RxABuffer,
        Duart0TxBBuffer,
        Duart0RxBBuffer,
        sizeof(Duart0TxABuffer)-1,
        sizeof(Duart0RxABuffer)-1,
        sizeof(Duart0TxBBuffer)-1,
        sizeof(Duart0RxBBuffer)-1,
        BAUD9600,BAUD9600,BITS8,STOP1,PARITYNONE,TXNONE,RXNONE, /* Channel A */
        BAUD9600,BAUD9600,BITS8,STOP1,PARITYNONE,TXNONE,RXNONE  /* Channel B */
        },
    {0,0}
    };

/****   Multiplexed Lamps */
const   LAMPSCFG    LampsCfg=
{
    8,      /* Default flash time */
    224     /* Default brightness */
};
/****   PIC */
const   PIC18CFG    PIC18Cfg[]=
{
    {&MbusDevice,0xC0}  /* MBUSDevice  I2CAddress PIC=C0*/
};

/****   Timers */
TIMER*  TimerLst[8];
const   WORD    NofTimers=(sizeof(TimerLst)/sizeof(TimerLst[0]));

TIMER*  FTimerLst[8];
const   WORD    NofFTimers=(sizeof(FTimerLst)/sizeof(FTimerLst[0]));

/****   Vacuum Fluorescent Displays */
const   VFD Vfd1=
{
    (UBYTE*)AUX0,       /* Clock */
    (UBYTE*)AUX1,       /* Data */
    (UBYTE*)AUX2,       /* Reset */
    3000,               /* reset delay */
    200                 /* inter-byte delay */
};


/*****   Stepper definitions */
/* Reel 1 Address*/
STEPPERVARS reel1_ram =
{
    0,0,        /* Step position/distance */
    0,          /* Direction */
    0,0,        /* Pattern table/index */
    0,          /* Vector table */
    0,0,0,      /* Delay table index timer */
    0,0,        /* Pix mask/opto count */
    0,0,        /* Spin/enable flags */
    0,0         /* Pos correction/tab missed */
};

STEPPERZVARS reel1_ram2;

const REEL_ADDR reel1_addr =
{
    REEL1_OPS,
    REEL1_IP
};

 /* Reel 2 Address*/
STEPPERVARS reel2_ram =
{
    0,0,        /* Step position/distance */
    0,          /* Direction */
    0,0,        /* Pattern table/index */
    0,          /* Vector table */
    0,0,0,      /* Delay table index timer */
    0,0,        /* Pix mask/opto count */
    0,0,        /* Spin/enable flags */
    0,0         /* Pos correction/tab missed */
};

STEPPERZVARS reel2_ram2;

const REEL_ADDR reel2_addr =
{
    REEL2_OPS,
    REEL2_IP
};

 /* Reel 3 Address*/
STEPPERVARS reel3_ram =
{
    0,0,        /* Step position/distance */
    0,          /* Direction */
    0,0,        /* Pattern table/index */
    0,          /* Vector table */
    0,0,0,      /* Delay table index timer */
    0,0,        /* Pix mask/opto count */
    0,0,        /* Spin/enable flags */
    0,0         /* Pos correction/tab missed */
};

STEPPERZVARS reel3_ram2;

const REEL_ADDR reel3_addr =
{
    REEL3_OPS,
    REEL3_IP
};

/* Reel 4 Address*/
STEPPERVARS reel4_ram =
{
    0,0,        /* Step position/distance */
    0,          /* Direction */
    0,0,        /* Pattern table/index */
    0,          /* Vector table */
    0,0,0,      /* Delay table index timer */
    0,0,        /* Pix mask/opto count */
    0,0,        /* Spin/enable flags */
    0,0         /* Pos correction/tab missed */
};

STEPPERZVARS reel4_ram2;

const REEL_ADDR reel4_addr =
{
    REEL4_OPS,
    REEL4_IP
};


const STEPPER reel1 =
{
    &reel1_addr,
    &RM161680,
    &reel1_ram,
    &reel1_ram2,
    0
};

const STEPPER reel2 =
{
    &reel2_addr,
    &RM161680,
    &reel2_ram,
    &reel2_ram2,
    0
};

const STEPPER reel3 =
{
    &reel3_addr,
    &RM161680,
    &reel3_ram,
    &reel3_ram2,
    0
};

const STEPPER reel4 =
{
    &reel4_addr,
    &RM161680,
    &reel4_ram,
    &reel4_ram2,
    0
};

 /* Reel List */
const   STEPPER* const  stepperlist[]=
{
        &reel1,
        &reel2,
        &reel3,
        &reel4,
        EOF_STEPPERS
};

const   STEPCFG StepperCfg=
{
    stepperlist,
    5,      /* No. of steps to wake up steppers */
    50,     /* delay between steps */
    50      /* opto delay */
};


/*  LED digit list */
const   DIGIT   LEDDigitLst[]=
{
    LED0,
    LED1,
    LED2,
    LED3,
    LED4,
    LED5,
    LED6,
    LED7,
    LED8,
    LED9,
    LED10,
    LED11,
    LED12,
    LED13,
    LED14,
    LED15,
    EOF_DIGITS
};

/**** Calypso 32 Video */

const   CALYPSO32CFG    Calypso32Cfg[]=
{
    { Cremson800x600, ( const RGB* )palette },
    { 0 }
};

/**** Calypso 32 Advanced Video */

const	CALYPSO32PLUSCFG	Calypso32PlusCfg[]=
	{
	{Calypso800x600, palette, CALYPSO32PLUS_BASE, CalypsoPlusISR, IntVideoLst, CalypsoPlusISR1ms},
	{0}
	};

const	CALYPSO32PLUSCFG	Calypso32Dual0Cfg[]=
	{
	{Calypso800x600, palette, CALYPSO32DUAL0_BASE, Calypso0ISR, IntVideo0Lst, Calypso0ISR1ms},
	{0}
	};

const	CALYPSO32PLUSCFG	Calypso32Dual1Cfg[]=
	{
	{Calypso800x600, palette, CALYPSO32DUAL1_BASE, Calypso1ISR, IntVideo1Lst, Calypso1ISR1ms},
	{0}
	};



/* ATA Compact Flash, Hard Drive */
const ATACFG ATACfg=
{
    1500, /* 1500Initialise time out */
};

/* storage driver to use with HSF audio driver */
const AUDIOHSFCFG AudioHSFCfg=
{
	&ATADevice,
};


/*************************************************************************/
